@@ -70,7 +70,7 @@ public class SocketClient implements Runnable {
             new nz.net.catalyst.lucene.server.Session().communicate(input, output, name);
             
         } catch (IOException e) {
-            throw new RtException("Error initialising new client connection " + name, e);
+            throw new RuntimeException("Error initialising new client connection " + name, e);
         } finally {
             try {
                 //hint to the garbage collector (this probably isn't needed however).
